package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````#9@$"#0```!(H@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(:(\`
M`&B/```%`````!````$```#0G@``T"X%"-`N!0A,`@``I!(```8`````$```
M`@```-R>``#<+@4(W"X%""`!```@`0``!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&2`@0``@`$%"(`!!0C<````W`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DT)X`
M`-`N!0C0+@4(,`$``#`!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`/UNK(W?``5(17`@849ES^R;$L`(E````00````@````(`````!P0!"5`
M!((X`4`!H(8!B,`!``)+*`0I.*(R1XH$#`A!````0P``````````````````
M`$4```!'````2`````````!)````2@```$P```!-````3@```$\`````````
M40``````````````4@```%,```!6``````````````!7````60```%H```!<
M`````````%X```!@````````````````````8@```&,`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!P^4_+/+;TQWZ
MH6Q@N8WQ#@````````````````````#J`@`````````````2````D`,`````
M````````$@```/(!`````````````!(````1```````````````@````_@,`
M````````````$@```($#`````````````!(```!"`0`````````````2````
M!0,`````````````$@```+,!`````````````!(```#Q`@`````````````2
M````#@$`````````````$@```#T!`````````````!(```"H`@``````````
M```2````/@,`````````````$@```+D"`````````````!(```!]`0``````
M```````2````3@,`````````````$@```$4#`````````````!(```">````
M```````````2````P0$`````````````$@```#(!`````````````!(```!W
M`@`````````````2````Z@$`````````````$@```-4"`````````````!(`
M``!:`0`````````````2````Q@(`````````````$@```&8!````````````
M`!(```#^```````````````2````50,`````````````$@```"T`````````
M`````"````")`@`````````````2````8@,`````````````$@```,(`````
M`````````!(```#C`@`````````````2````EP,`````````````$@```.,!
M`````````````!(````=`0`````````````2````:@``````````````$@``
M`,`"`````````````!(```"6`@`````````````2````"P(`````````````
M$@```,X"`````````````!(```"6`0`````````````2````=0``````````
M````$@````P#`````````````!(```#S```````````````2````T0``````
M````````$@```(D#`````````````!(```#<`@`````````````2````D```
M````````````$@```#P``````````````"````"!```````````````2````
MN0``````````````$@```&D#`````````````!(```#W`@`````````````2
M````4```````````````(````(X"`````````````!(````M`P``````````
M```2````]P$`````````````$@```!H#`````````````!(````<`@``````
M```````2````GP(`````````````$@```"4#`````````````!(```!S`P``
M```````````2````1P$``+"4!`@`````$@```'8$``#(P`0(!````!$`#P`L
M!```X+`$"/D*```2``T`?00``*"M!`BW`0``$@`-`-4#``"TP`0(`````!(`
M#@"K`P``(#$%"`0````A`!D`VP,``+"J!`@%````$@`-`%P$``!0P`0(70``
M`!(`#0#B````8)4$"``````2````BP$``"PQ!0@$````$0`9`#D$```,,04(
M`````!``&``W`P``*#$%"`0````1`!D`.P0```PQ!0@`````(``8`*H#```@
M,04(!````"$`&0#+`P``L,`$"`(````2``T`;`0``!@Q!0@$````$0`8`)($
M``#`J@0(N`$``!(`#0"L````,#$%"`$````1`!D`J0,``"`Q!0@$````$0`9
M`*0#```PE@0(W0$``!(`#0"Q!```8*\$"$P````2``T`[`,``+"O!`@D````
M$@`-``<$``"0OP0(=````!(`#0"Z`P``'#$%"``````0`!D`Q@,``'1!!0@`
M````$``9`&@"``#,P`0(!````!$`#P"_!```X+L$"*D#```2``T`1@0``/"I
M!`BQ````$@`-`#\$```-F`0(`````!(`#0!M`0``L)($"``````2````(`0`
M`+"L!`CG````$@`-`+,#```<,04(`````!``&``3!```@*P$""T````2``T`
MB@0``'"I!`@G````$@`-`*0!```T,04($P```!$`&0"?!```X*\$"/L````2
M``T`C`0``/R1!`@`````$@`+``!L:6)P97)L+G-O+C4N,C(`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E
M<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7VYE=UA3
M`%!E<FQ?;6=?<V5T`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?879?9F5T8V@`4&5R
M;%]S=E]S971P=@!03%]D;U]U;F1U;7``<&5R;%]R=6X`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]N97=84U]F;&%G<P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?<&%R
M<V4`4&5R;%]G=E]F971C:'!V`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`'!E<FQ?86QL;V,`<&5R;%]F<F5E`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-A9F5S>7-M86QL;V,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M9&5S=')U8W0`4$Q?=&AR7VME>0!097)L7W-Y<U]T97)M`%!,7VUE;6]R>5]W
M<F%P`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`;&EB<'1H<F5A
M9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H<F5A9%]G971S<&5C:69I
M8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8FYS;"YS;RXQ`&QI8F1L+G-O
M+C(`;&EB;2YS;RXV`&QI8F-R>7!T+G-O+C$`;&EB=71I;"YS;RXQ`&QI8F,N
M<V\N-@!?24]?<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T
M<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI
M;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`
M<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C
M:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED
M`')E861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V
M-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`
M7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D
M:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`<&%R7V-U<G)E;G1?
M97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V9P7VAW`'!A
M<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB
M<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"
M0U\R+C(`1TQ)0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#
M7S(N-``````"``(``P````(``@`"``(````"```````$``(``@````(``@``
M```````%``8``@````(``@````<````"``(````"``(`!@```````@`"``,`
M`@``````!P```````@`"````````````"``'`````@`(``,`"``#``(``@`'
M`````0`!``$``0`"``$``0```````0`"``$``@`!``$``0````(``0`!``$`
M`0`!``$``0`!``$``0````$``0`!``$````!``$``0`"`-,!```0````,```
M`!)I:0T```8`U00``!`````0:6D-```#`-\$`````````0`%`%X"```0````
M`````!)I:0T```@`U00``!````!T&6D)```'`.D$```0````<AEI"0``!0#U
M!```$````!1I:0T```0``04``!`````0:6D-```"`-\$````````_"\%"`8>
M```@,04(!5,``"@Q!0@%3```+#$%"`5*```P,04(!5(``#0Q!0@%8P``##`%
M"`<!```0,`4(!P(``!0P!0@'`P``&#`%"`<%```<,`4(!P8``"`P!0@'!P``
M)#`%"`<(```H,`4(!PD``"PP!0@'7@``,#`%"`<*```T,`4(!PL``#@P!0@'
M#```/#`%"`<-``!`,`4(!PX``$0P!0@'#P``2#`%"`<0``!,,`4(!Q$``%`P
M!0@'$@``5#`%"`<3``!8,`4(!Q0``%PP!0@'%0``8#`%"`<6``!D,`4(!Q<`
M`&@P!0@'&```;#`%"`<9``!P,`4(!QH``'0P!0@'&P``>#`%"`<<``!\,`4(
M!QT``(`P!0@''@``A#`%"`<?``"(,`4(!R```(PP!0@'(0``D#`%"`<B``"4
M,`4(!R,``)@P!0@')```G#`%"`<E``"@,`4(!R8``*0P!0@')P``J#`%"`<H
M``"L,`4(!T$``+`P!0@'*0``M#`%"`<J``"X,`4(!RL``+PP!0@'+```P#`%
M"`<M``#$,`4(!RX``,@P!0@'+P``S#`%"`<P``#0,`4(!S$``-0P!0@',@``
MV#`%"`=)``#<,`4(!S0``.`P!0@'-0``Y#`%"`<V``#H,`4(!S<``.PP!0@'
M.0``\#`%"`<Z``#T,`4(!SL``/@P!0@'/```_#`%"`<]````,04(!SX```0Q
M!0@'/P``"#$%"`=```!3@^P(Z"L&``"!P_N=``"+@_S___^%P'0%Z.8!``"#
MQ`A;PP#_-00P!0C_)0@P!0@`````_R4,,`4(:`````#IX/____\E$#`%"&@(
M````Z=#_____)10P!0AH$````.G`_____R48,`4(:!@```#IL/____\E'#`%
M"&@@````Z:#_____)2`P!0AH*````.F0_____R4D,`4(:#````#I@/____\E
M*#`%"&@X````Z7#_____)2PP!0AH0````.E@_____R4P,`4(:$@```#I4/__
M__\E-#`%"&A0````Z4#_____)3@P!0AH6````.DP_____R4\,`4(:&````#I
M(/____\E0#`%"&AH````Z1#_____)40P!0AH<````.D`_____R5(,`4(:'@`
M``#I\/[___\E3#`%"&B`````Z>#^____)5`P!0AHB````.G0_O___R54,`4(
M:)````#IP/[___\E6#`%"&B8````Z;#^____)5PP!0AHH````.F@_O___R5@
M,`4(:*@```#ID/[___\E9#`%"&BP````Z8#^____)6@P!0AHN````.EP_O__
M_R5L,`4(:,````#I8/[___\E<#`%"&C(````Z5#^____)70P!0AHT````.E`
M_O___R5X,`4(:-@```#I,/[___\E?#`%"&C@````Z2#^____)8`P!0AHZ```
M`.D0_O___R6$,`4(:/````#I`/[___\EB#`%"&CX````Z?#]____)8PP!0AH
M``$``.G@_?___R60,`4(:`@!``#IT/W___\EE#`%"&@0`0``Z<#]____)9@P
M!0AH&`$``.FP_?___R6<,`4(:"`!``#IH/W___\EH#`%"&@H`0``Z9#]____
M):0P!0AH,`$``.F`_?___R6H,`4(:#@!``#I</W___\EK#`%"&A``0``Z6#]
M____);`P!0AH2`$``.E0_?___R6T,`4(:%`!``#I0/W___\EN#`%"&A8`0``
MZ3#]____);PP!0AH8`$``.D@_?___R7`,`4(:&@!``#I$/W___\EQ#`%"&AP
M`0``Z0#]____)<@P!0AH>`$``.GP_/___R7,,`4(:(`!``#IX/S___\ET#`%
M"&B(`0``Z=#\____)=0P!0AHD`$``.G`_/___R78,`4(:)@!``#IL/S___\E
MW#`%"&B@`0``Z:#\____)>`P!0AHJ`$``.F0_/___R7D,`4(:+`!``#I@/S_
M__\EZ#`%"&BX`0``Z7#\____)>PP!0AHP`$``.E@_/___R7P,`4(:,@!``#I
M4/S___\E]#`%"&C0`0``Z4#\____)?@P!0AHV`$``.DP_/___R7\,`4(:.`!
M``#I(/S___\E`#$%"&CH`0``Z1#\____)00Q!0AH\`$``.D`_/___R4(,04(
M:/@!``#I\/O__XU,)`2#Y/#_<?Q5C4$(B>564U&)RX/L(%"-00104>C=_?__
M@\0,:+"4!`AHL)0$"&A@E00(Z*8I``"#Q!"`/3`Q!0@`=3'H]?S__X7`HW!!
M!0@/A'L!``"#[`Q0Z#_\__]9_S4L,04(Z#/___^#Q!#&@%D%````@^P,_S4L
M,04(Z!O___^`B/8"```"6O\U+#$%".@(____@(CV`@```8L#@\00@\`%/?__
M_S\/A_@```"#[`S!X`)0Z,+\__^+<P2+&X/$$*-D004(QP5H004(!````(L6
M@_L!QT`$J\($",=`#*["!`B)$(L5&#$%"(E0"+H!````?A2-M@````"+#):)
M3)`,@\(!.=IU\H/L#,=$F`P`````@\,#:@!04VB@J00(_S5P004(Z+#]__^#
MQ""%P(G#=$6#[`S_-7!!!0CHJ?O__XU5Y+AOP00(Z%P,``"#Q!"%P'0X@^P,
M_S5P004(Z$?[___H0OW__X/$$(UE](G865M>78UA_,.#[`S_-7!!!0CHQ/W_
M_X/$$(G#ZZ:A;$$%"(7`=!^#[`Q0Z+LG``"#Q!#KL5!0:#0Q!0AH'\$$".B%
M_/__C57DN"3!!`CHZ`L``(7`HVQ!!0ATBNO)@^P,:@'H`_S__S'M7HGA@^3P
M4%12:+#`!`AH4,`$"%%6:#"6!`CH(OS___20BQPDPV:09I!FD&:09I!FD+@?
M,04(+1PQ!0B#^`9V&K@`````A<!T$56)Y8/L%&@<,04(_]"#Q!#)\\.0C70F
M`+@<,04(+1PQ!0C!^`*)PL'J'P'0T?AT&[H`````A=)T$E6)Y8/L$%!H'#$%
M"/_2@\00R?/#C70F`(V\)P````"`/4<Q!0@`=1-5B>6#[`CH?/___\8%1S$%
M"`')\\-FD+C8+@4(BQ"%TG4%ZY.-=@"Z`````(72=/)5B>6#[!10_]*#Q!#)
MZ77___]FD&:0D%57C4@<5E.![%@!``")1"0$,<"0C70F`(L4@0_*B52$&(/`
M`8/X$'7OC50D3(V,)$P!``"-="8`BP(S0NR#P@0S0M`S0LC1P(E""#G*=>F+
M1"0$BU0D&(L8BV@0BT@,B=^+6`0!ZHG^B6PD%(E,)`C!Q@6)?"0,B1PDBU@(
MC90RF7F"6HG=B=Z+'"0QSHEL)!")\(G^(=C!S@(QR(GI`=")VHM<)`C!R@(#
M7"0<,=$A^3'I`VPD((V<&9EY@EJ)P<'!!0'+B=$Q\2'!P<@",=$#5"0DC;PI
MF7F"6HG9P<$%`?F)]S''(=_!RP(Q]P-T)"B-O#J9>8):B<K!P@4!^HG',=\A
MSS''C;P^F7F"6HG6P<8%P<D"`T0D+`'WB=XQSB'6P<H",=X#7"0PC;0PF7F"
M6HGXP<`%`<:)R#'0(?@QR`-,)#2-G`.9>8):B?#!P`4!PXGXB=?!R`(QQR'W
MP<X",=<#5"0XC;PYF7F"6HG9P<$%`?F)QS'W(=_!RP(QQXV\.IEY@EJ)RL'"
M!0'ZB?<QWR'/`T0D/,')`C'W`W0D0(V\.)EY@EJ)T,'`!0'XB=\QSR'7P<H"
M,=\#7"1$C;P^F7F"6HG&P<8%`?Z)SS'7(<?!R`(QSP-,)$B-O#N9>8):B?/!
MPP4!^XG7,<<A]\'.`C'7`U0D3(V\.9EY@EJ)V<'!!0'YB<<Q]R'?,<>-O#J9
M>8):B<K!P@4!^L'+`@-$)%")]S'?(<_!R0(Q]P-T)%2-O#B9>8):B=#!P`4!
M^(G?,<\AU\'*`C'?`UPD6(V\/IEY@EJ)QL'&!0'^B<\QUR''P<@",<\#3"1<
MC;P[F7F"6HGSP<,%`?N)US''(??!S@(QUXV\.9EY@EJ)V<'!!0'YB<<Q]R'?
M,<<#5"1@P<L"`T0D9(V\.IEY@EJ)RL'"!0'ZB?<QWR'/P<D",?>-O#B9>8):
MB=#!P`4!^(M\)&B-O#ZAZ]ENB=XQSC'6P<H"`?Z)Q\''!0'^BWPD;(V\.Z'K
MV6Z)RS'3,</!R`(!^XGWP<<%`?N+?"1PC;PYH>O9;HG1,<$Q\<'.`@'YB=_!
MQP4!^8M\)'2-O#JAZ]ENB<(Q\C':`?J)S\'+`L''!0'ZBWPD>(V\.*'KV6Z)
M\#'8,<C!R0(!^(G7P<<%`?B+?"1\C;P^H>O9;HG>,<XQUL'*`@'^B<?!QP4!
M_HN\)(````"-O#NAZ]ENB<LQTS'#P<@"`?N)]\''!0'[B[PDA````(V\.:'K
MV6Z)T3'!,?'!S@(!^8G?P<<%`?F+O"2(````C;PZH>O9;HG",?(QV@'ZB<_!
MQP4!^HN\)(P```#!RP*-O#BAZ]ENB?`QV#'(P<D"`?B)U\''!0'XB[PDD```
M`(V\/J'KV6Z)WC'.,=;!R@(!_HG'P<<%`?Z+O"24````C;P[H>O9;HG+,=,Q
MP\'(`@'[B??!QP4!^XN\))@```"-O#FAZ]ENB=$QP3'QP<X"`?F)W\''!0'Y
MB[PDG````(V\.J'KV6Z)PC'R,=K!RP(!^HG/P<<%`?J+O"2@````C;PXH>O9
M;HGP,=@QR,')`@'XB=?!QP4!^(N\)*0```"-O#ZAZ]ENB=XQSC'6P<H"`?Z)
MQ\''!0'^B[PDJ````(V\.Z'KV6Z)RS'3,</!R`(!^XGWP<<%`?N+O"2L````
MC;PYH>O9;HG1,<$Q\<'.`@'YB=_!QP4!^8N\)+````"-O#JAZ]ENB<(Q\C':
MP<L"`?J)SXG=P<<%`?J+O"2T````C;PXH>O9;HGP,=@QR`'XB=?!R0(#M"2X
M````P<<%"<T!^(G?(=4AS\'*`@.<)+P````)[XG-C;P^W+P;CXG&"=7!Q@4A
MQ<'(`@'^B<\#C"3`````(=<)[XG5C;P[W+P;CXGS"<7!PP4A]<'.`@'[B=<A
MQPGOB<6-O#G<O!N/B=D)]<'!!2'=`?F)QR'W">\#E"3$````B?7!RP(#A"3(
M````"=TAS8V\.MR\&X^)RL')`L'"!0'ZB?<#M"3,````(=\)[XG=C;PXW+P;
MCXG0"<W!P`4AU<'*`@'XB=\#G"30````(<\)[XG-C;P^W+P;CXG&"=7!Q@4A
MQ<'(`@'^B<\AUPGOB=6-O#O<O!N/B?,)Q<'#!2'U`?N)UR''">\#C"34````
MB<7!S@(#E"38````"?4AW8V\.=R\&X^)V<'+`L'!!0'YB<<#A"3<````(?<)
M[XGUC;PZW+P;CXG*"=W!P@4AS<')`@'ZB?<#M"3@````(=\)[XG=C;PXW+P;
MCXG0"<W!P`4AU<'*`@'XB=\ASPGOB<V-O#[<O!N/B<8)U<'&!2'%`?Z)SR'7
M">\#G"3D````B=7!R`(#C"3H````"<4A]8V\.]R\&X^)\\'.`L'#!0'[B=<#
ME"3L````(<<)[XG%C;PYW+P;CXG9"?7!P04AW<'+`@'YB<<#A"3P````(?<)
M[XGUC;PZW+P;CXG*"=W!P@4AS<')`@'ZB?<AWPGOB=V-O#C<O!N/B=`)S<'`
M!2'5`?B)WR'/">\#M"3T````P<H"`YPD^````(VL/MR\&X^)QHG/P<8%"=<!
M]8G.(<<AUL'(`@.,)/P````)_HVT,]R\&X^)Z\'#!0'>B=,)PXG?B=,#E"0`
M`0``(>\APPG[C;P9W+P;CXGSB<'!PP4!WXGKP<L""=F)S8G!(?4AV<'.`@GI
MC8P*W+P;CXGZP<(%`<J)\8G>"<Z)]8G>(?TAS@GN`X0D!`$``,'/`HVT,-R\
M&X^)T,'`!0'PB[0D"`$``(VT,];!8LJ)RS'[,=/!R@(!\XG&P<8%`?.+M"0,
M`0``C;0QUL%BRHGY,=$QP0'QB=[!Q@4!\8G&BX0D$`$``,'.`HVL!];!8LJ)
MT(G/,?#!QP4QV,'+`@'H`<>+A"04`0``C90"UL%BRHGP,=@QR,')`@'0B?K!
MP@4!T(N4)!@!``"-K!;6P6+*B=J)QC'*P<8%,?H!Z@'6BY0D'`$``,'/`HV<
M$];!8LJ)RC'Z,<(!VHGSP<,%`=J)PXN$)"`!``#!RP*-K`'6P6+*B?B)T3'8
MP<$%,?#!S@(!Z`'!BX0D)`$``(V\!];!8LJ)V#'P,=#!R@(!^(G/P<<%`?B)
MUXN4)"@!``"-K!/6P6+*B?,Q^XG:B<,QRL'#!<')`@'J`=.+E"0L`0``C;06
MUL%BRHGZ,<HQP@'RB=[!Q@4!\HG&BX0D,`$``,'.`HVL!];!8LJ)R(G7,?#!
MQP4QV,'+`@'H`<>+A"0T`0``C8P!UL%BRHGP,=@QT,'*`@'(B?G!P04!R(G1
MBY0D.`$``(VL%M;!8LJ)VHG&,<K!Q@4Q^L'/`@'J`=:+E"0\`0``C9P3UL%B
MRHG*,?HQP@':B?/!PP4!VHG#BX0D0`$``,'+`HVL`=;!8LJ)^(G1,=C!P04Q
M\,'.`@'H`<&+A"1$`0``C;P'UL%BRHG8,?`QT`'XB<_!R@+!QP4!^(N\)$@!
M``"-O#O6P6+*B?,QTS'+P<D"`?N)Q\''!0'[B[PD3`$``(V\/M;!8LJ)UC'.
M,<;!R`(!_HG?P<<%`?Z+O"10`0``C;PZUL%BRHG*,<(QVL'+`@'ZB??!QP4!
M^HM\)`P#O"14`0``C;PYUL%BRHG!,=DQ\<'.`@'YB=?!QP4!^8M\)`2)#P,4
M)(ML)!`#7"0(`T0D%(E7!(T4+HE?#(E7"(E'$('$6`$``%M>7UW#C78`C;PG
M`````(7`#X2;````55=64X/L'(L-(#$%"(7)B4PD"'15#[8(A,ET7(#Y/717
MB<.#PP$/M@N$R70%@/D]=?$IPXM,)`B+*87M="R)5"0,B<:)SV:0@^P$4U95
MZ'7Q__^#Q!"%P'4'@'P=`#UT'X/'!(LOA>UUWH/$'#'`6UY?7<.-="8`,=OK
MN(UT)@")^BM4)`B+1"0,P?H"B1"#Q!R-1!T!6UY?7<,QP,.-=@"-O"<`````
M4XG#@^P8C50D#(G8Z#____^%P'0VC78`BU0D#*$@,04(C020BU`$A=*)$'39
MC78`@\`$BU`$A=*)$'7TC50D#(G8Z`G___^%P'7-@\086\-55XG'5E,QP(G3
M@^PX@#H]#Y3``<-3Z$7O__^#Q!")Q8GXC50D'.C5_O__A<`/A.T```"#[`R)
MQE#H(N___X/$$#G%#X:_````BT0D'(T,A0`````/M@>$P`^$=P$``#P]#X1O
M`0``B?CK"I"-="8`@/H]=`J#P`$/MA"$TG7Q*?B-1"@"@^P,BS4@,04(4`'.
MZ%KN__^#Q!"%P(D&#X1&`0``H2`Q!0B+5"0<C4\!BQ20#[8'/#V(`G0AA,!U
M#>L;C;0F`````#P]=!"#P0$/MD'_@\(!A,"(`G7LQ@(],<"-M"8`````#[8,
M`XA,`@&#P`&$R77Q,<"#Q"Q;7E]=PXVT)@````"#PP$/MD/_@\8!A,"(1O]U
M[^O<D(UT)@"+%2`Q!0B+,H7V#X2M````,<#K!HUT)@")\(UP`8L,LH7)=?2-
M!(4,````BPU@004(A<ET,X/L"%!2Z('M__^#Q!"%P*,@,04(='Z-#+4`````
MQT2P!`````")="0<Z='^__^0C70F`(E4)`B#[`S'!6!!!0@!````4.A1[?__
M@\00A<!T0XT,M0````"#[`11BU0D$(E,)!12B40D%%#HS.O__XM$)!B#Q!"+
M3"0,HR`Q!0CKG#'`Z:3^__^X"````#'VZ6+___^X_____^D&____C;8`````
MC;PG`````(7`=`6`.`!U!\.-M@````!55U93B<:![(@```!0Z`[O__^#Q!"%
MP(G'#X3E````D(/L#%?H=^[__X/$$(7`B<,/A+H```"`>Q,N#X2(````@^P,
MC6L35N@$[?__B2PDB40D'.CX[/__BTPD'(U$`0*)!"3H>.S__XG#6%I55FC0
MP`0(:O]J`5/HL^[__X/$'(U$)!104VH#Z$/N__^#Q!"#^/]T$(M$)"`E`/``
M`#T`0```=&N#[`Q3Z'+K__^#Q!"#[`Q3Z-;J__^#Q!#I7O___XVV``````^V
M0Q2$P`^$3/___SPN#X5D____@'L5``^$.O___^E5____D(UT)@"#[`Q7Z!?N
M__^)-"3HS^K__X/$$(/$?%M>7UW#C70F`(G8Z-G^___KF(VT)@````!3B<.#
M[!3_-2PQ!0CHK^W__X/$#`4D`0``4%-J`^BN[?__@\00A<!T!X/$"#'`6\.#
M[`S_-2PQ!0CH@NW__XN`-`$``(/$$"4`\```/0!```!T(X/L#/\U+#$%".A?
M[?__BX`T`0``@\00)0#P```]`*```'6S@^P(:@)3Z)_L__^#Q!"%P`^4P(/$
M"`^VP%O#ZPV0D)"0D)"0D)"0D)"055>)QU93B=6!["`0``!EH10```")A"00
M$```,<!H_P\``(UT)!16:-;`!`CH7^K__X/$$(7`?F"-6/^`?!P,`'1.B<.#
M[`13:B]6Z-#K__^#Q!"%P'1!@^P,_S4L,04(Z+OL__]35E=0Z%+L__^#Q""+
MA"0,$```93,%%````'4U@<0<$```6UY?7<.-="8`A=MUL(UT)@"#[`S_-2PQ
M!0CH>NS__X/$#%574.COZ?__@\00Z[OHA>G__Y"-="8`@^P8_S4L,04(Z%+L
M__]HV,($"&BPD@0(:.7`!`A0Z.WJ__^#Q"S#B?:-O"<`````@^P8_S4L,04(
MZ"+L__^)!"3HNO___UC_-2PQ!0CH#NS__UI9:@!HI<($"&BEP@0(:."[!`AH
M`<$$"%#H0.O__X/$+,.-M@````"-OP````!75E.![!`@``!EH10```")A"0,
M(```,<#HD^G__X/L"&CAP`0(4&@6P00(:`$0``!J`8U<)"93Z/3K__^#Q""%
MP'AE@^P$:``0``"-O"03$```5U/H]^C__X/$$(7`B<9X1HU``8/L#%#H<NG_
M_X/$$(7`B<-T,8/L!%974.@>Z/__Q@0S`(/$$(G8BY0D#"```&4S%10```!U
M$8'$$"```%M>7\.-=@`QP.O?Z$_H___K#9"0D)"0D)"0D)"0D)#I.____XUT
M)@"-O"<`````55=64X'L+!```(N<)$`0``"-5"08B[PD1!```&6A%````(F$
M)!P0```QP+@DP00(Z.OX__^#[`B)QFHO4^@>Z?__@\00A<!T+8G:N"W!!`CH
MR_G__XG8BY0D'!```&4S%10````/A4@!``"!Q"P0``!;7E]=PX/L#%/H`>G_
M_UI9B40D%&@ZP00(5^CPZ?__@\00B<6+1"0,C7PD'(/``8E$)`R-="8`A>UT
MG8!]``!U!;TBP00(A?9T%8/L"%56Z+OF__^#Q!"%P`^$FP```(/L#%7HI^C_
M_X/$$(!\!?\O=120C70F`(/H`8!\!?\OQD0%``!T\0-$)`P]_P\```^/0___
M_X/L!%-H/,$$"%5H8,($"&@`$```:@%7Z#[J__^#Q!3_-2PQ!0CHX.G__X/$
M#`4D`0``4%=J`^B_Z?__@\00A<!U(X/L#/\U+#$%".BZZ?__BX`T`0``@\00
M)0#P```]`(```'09@^P(:#K!!`AJ`.@&Z?__@\00B<7I)/___X/L"&H!5^CA
MZ/__@\00A<!UU8GZN"W!!`CH?OC__X/L#%?H->C__X/$$.FD_O__Z'CF__^0
MC;0F`````(M$)`0/M@B$R70@C5`!ZPH/M@J#P@&$R701@/DO=?$/M@J)T(/"
M`83)=>_SPXUV`%.#[!B+7"0@A=MT1`^V$X32=#V(5"0/@^P,4^APY___C40#
M_X/$$`^V5"0/.<-R#^M*C;8`````@^@!.<-T08`X+W3TZR^-=@"-O"<`````
M@^P,:@+HQN;__X/$$(7`='^Z+@```&:)$(/$&%O#9I"`."]T,(/H`3G#<O0Y
MPW4E@/HO=,O'1"0@/,$$"(/$&%OI6N?__XUV`(V\)P````"`."]U!X/H`3G#
M<O0IV(U0`H'Z`!```'<G@\`!:``0``!04VA@,04(Z(/G__^#Q!"X8#$%"(/$
M&%O#C;8`````@\08,<!;PXGVC;PG`````%=6@^PT9:$4````B40D+#'`H;3"
M!`B)1"0*H;C"!`B)1"0.H;S"!`B)1"02H<#"!`B)1"06H<3"!`B)1"0:H<C"
M!`B)1"0>H<S"!`B)1"0BH=#"!`B)1"0F#[<%U,($"&:)1"0JN#[!!`CH@?;_
M_[A'P00(Z'?V__^X3\$$".AM]O__N%C!!`CH8_;__[A?P00(Z%GV__^X;\$$
M".A/]O__N"3!!`CH1?;__[A[P00(Z#OV__^XA<$$".@Q]O__N(_!!`CH)_;_
M_[@MP00(Z!WV__^XF<$$".@3]O__N*+!!`CH"?;__XU4)`2XK<$$".A+]?__
MA<!T#(G"N(7!!`CH._;__XU4)`2XOL$$".@M]?__A<!T#(G"N-#!!`CH'?;_
M_XU4)`2XV\$$".@/]?__A<!T,XG"N"3!!`CH__7__[H'P@0(N%_!!`CH\/7_
M_XM$)"QE,P44````=56#Q#1>7\.0C70F`(U4)`2XZ\$$".C*]/__A<!T%HG"
MN'O!!`CHNO7__^NYD(VT)@````"-="0;O_S!!`BY"@```/.F=9^-5"0EN'O!
M!`CHD/7__^N/Z)GC__^)]HV\)P````"A%#$%"(/X_W0&PY"-="8`@^P<N'O!
M!`B-5"0,Z%_T__^%P'0C#[80@/HP#Y7`A-(/E<(/MM(AT*,4,04(@\0<PXVT
M)@`````QP.OLC70F`(/L#.A(X___@^P,4.B?XO__@\00A<!T"(L`@\0,PV:0
M,<#K]HVV`````(V_`````%57OQ/"!`A64[L)P@0(@^P\QT0D%!/"!`C'1"08
M"<($"(UT)!S'1"0<%L($",=$)"`,P@0(QT0D)!'"!`C'1"0H(\($",=$)"P`
M````ZR*0@^P(_W0D6%#H\^'__X/$$(7`=#R%VW0NBP:)WX/&!(G#C50D$(GX
MZ(3S__^%P(G%=`6`.`!UR8M4)%")^.AN]/__A=MUTH/$/%M>7UW#9I"#[`S_
M="1<Z+3C__^)+"2)1"0<Z*CC__^+5"0<C40"`HD$).@HX___@\0,56@ZP00(
M_W0D7&A@P@0(:O]J`5")1"0LZ%CE__^#Q""+5"0,B?CH"O3__^EI____D(UT
M)@!55U93@>S\@```BX0D$($``(U4)!C'1"0<.L($",=$)"`BP00(QT0D)```
M``#'1"0TT,$$",=$)#C)P00(B40D",=$)#P_P@0(9:$4````B80D[(```#'`
MN"3!!`C'1"1`YL$$",=$)$1'P@0(QT0D2`````#'1"0H+L($",=$)"Q+P@0(
MQT0D,`````#H;O+__X7`=`F`.``/A?$#``#H+/[__X7`B<,/A`,$``"#[`Q3
MZ*GB__^-1``!@\00@^P,4.@IXO__@\00@#L`B<:)QW0ID(UT)@`/M@.#[`R#
MPP%0:%3"!`AJ_VH!5X/'`NA,Y/__@\0@@#L`==R-?"0XN-#!!`CK$XGVC;PG
M`````(/'!(M'_(7`=#:-5"08Z-WQ__^%P(G#=.>`.`!TXNC]]?__A<!TV8/L
M#%/H@.+__X/$$(7`B<5U68VT)@````"+7"0<A=MT2(`[`+\!````=1;K/(UT
M)@"+7+P<A=MT,(/'`8`[`'0HB=CHL?7__X7`=.6#[`Q3Z#3B__^#Q!"%P'35
MB<7K"XGVC;PG`````#'M@^P,B?-5Z+/A__^#Q!"+"X/#!(V1__[^_O?1(<J!
MXH"`@(!TZ??"@(```'4&P>H0@\,"B=$`T8/;`X/L#"GSC9P#!`0``%/H`N'_
M_XE$)!16B<9H6<($"&@\P00(56A>P@0(:O]J`5#H,>/__X/$*&C``0``5NB3
MX?__@\00@_C_='.#[`S_-2PQ!0CHO>+__X/$#`4D`0``4/]T)`QJ`^BYXO__
M@\00A<!T<H/L#/]T)!"+1"08_S!H(,,$"&H!_S4H,04(Z%/B__^#Q"`QP(N,
M).R```!E,PT4````#X5N"```@<3\@```6UY?7<.-M"8`````Z$/A__^+`(/X
M$72!@^P(4/]T)!"+1"08_S!HY,($".NGC;0F`````(/L#/\U+#$%".@BXO__
MBX`T`0``@\00)0#P```]`$````^%9____X/L#/\U+#$%".C[X?__B[`\`0``
MZ"#?__^#Q!`YQ@^%0____X/L#/\U+#$%".C7X?__BX`T`0``@\00)?\!```]
MP`$```^%'/___X/L#%/HM=___XU4)"B)Q;@,P@0(Z+7O__^#Q!"%P`^$L@$`
M`(/L#%#H8>#__U]:4(M$)!3_,.AS]O__@\00A<")PP^$C@$``(/L#%/HW=__
M_X/$$(/X`WXMC70#_+]GP@0(N04```#SIG4;@_@$#X3?!0``@'P#^R\/A-0%
M``"-M"8`````Z,/Z__^%P'4:@^P(:@!3Z+3?__^)1"08@\00A<`/A3@!``"Z
M!\($"+A[P00(,=OH%/#__^C/WO__:*7"!`A0:#S!!`B+="005FB`P@0(:O]J
M`57H,.'__X/$(.LWC78`Z,/?__^#.!%U0.B9WO__@\,!@^P,:*7"!`A34&@\
MP00(5FB.P@0(:O]J`57H]^#__X/$,(/L"&C``0``5>A6W___@\00@_C_=+:#
M[`S_="00Z#+=__^)ZK@DP00(Z(;O__^)+"3H?OK__X/$$(GHZ>;]__^-="8`
M@^P,4(E$)!3H8_K__XM$)!2)!"3H%]___X/$$.G!_?__O@$```"X+L($".L.
MC78`BT2T*(/&`87`="F-5"08Z"SN__^%P'3H@#@`=..#[`Q0Z-K>__^#Q!"%
MP'33B</INOO__[@-````NS/"!`CIN_O__Y"-="8`BT0D"(L8Z6?^__]J`FK_
M:NZ+="045NB-W?__@\0,:@:-A"3T````4%;H.MS__X/$$("\).P`````=0Z`
MO"3M````0P^$"`4``&H`:@!J`/]T)!3H4-W__\>$))P````!(T5GQX0DH```
M`(FKS>_'A"2D````_MRZF,>$)*@```!V5#(0QX0DK````/#ATL/'A"2P````
M`````,>$)+0`````````QX0D^`````````"#Q!");"0,D(/L!&@`@```C80D
M]````%#_="04Z)?;__^#Q!"%P(G##XZF`0``BX0DH````(T4V#G0BX0DI```
M`'8#@\`!B90DH````(G:P>H=`=")A"2D````BX0DZ````(7`#X1>`0``ND``
M``")WBG".=-^`HG6C8PDJ````(/L!%8!R(V,)/0```!14.ADV___BX0D^```
M``'PB80D^````(/$$(/X0`^%6/___XV$).P````I\XTL,(V$)(P```#HH.'_
M_X/[/P^.10,``(/K0(G?P>\&C7<!P>8&`>Z-M"8`````BT4`@\5`B80DJ```
M`(M%Q(F$)*P```"+1<B)A"2P````BT7,B80DM````(M%T(F$)+@```"+1=2)
MA"2\````BT78B80DP````(M%W(F$),0```"+1>")A"3(````BT7DB80DS```
M`(M%Z(F$)-````"+1>R)A"34````BT7PB80DV````(M%](F$)-P```"+1?B)
MA"3@````BT7\B80DY````(V$)(P```#HT>#__SGN#X5)____P><&*?MJ1%-6
MC80DM````%#HH]O__XF<)/@```"#Q!#I1/[__XUT)@"-K"3L````Z?3^__^+
M;"0,@^P,_W0D%.ATW?__BYPDL````(N4)+0```")V<'I`X/A/XU!`<:$#+@`
M``"`@\00@_@X#X\,`@``N3@```"-M"2H````*<$!\(/Y!`^#.P(``(7)=`SV
MP0+&```/A?8"``")T(B4).,```"(G"3G````P>@8C7PD8XUT)%"(A"3@````
MB=#!Z!"(A"3A````B=#!Z`B(A"3B````B=C!Z!B(A"3D````B=C!Z!"(A"3E
M````B=B-G"2+````P>@(B(0DY@```(V$)(P```#HO=___XN4)(P```")T8A4
M)%+!Z1@/ML&(3"1/B='!Z1"(3"10B=&+E"20````P>D(B$PD48G1B%0D5L'I
M&(A,)%.)T<'I$(A,)%2)T8N4))0```#!Z0B(3"15B=&(5"1:P>D8B$PD5XG1
MP>D0B$PD6(G1BY0DF````,'I"(A,)%F)T8A4)%[!Z1B(3"1;B='!Z1"(3"1<
MB=&+E"2<````P>D(B$PD78G1B%0D8L'I&(A,)%^)T<'I$(A,)&")T<'I"(A,
M)&'K$(UV`(V\)P`````/M@:#Q@&#[`Q0:%3"!`AJ_VH!5X/'`NCTV___@\0@
M.?MUW<:$)(L`````:*7"!`B-1"1G4&@\P00(_W0D$&AQP@0(:O]J`57HP]O_
M_X/$(.G=^O__BT0D"(M0!(72#X0D^O__@^P,4HE4)!CHO]G__X/$$(/X`P^&
M"_K__XM4)`B_;,($"+D%````C70"_/.F#X7Q^?__B=/IZOG__XGNZ8?]__^-
MM"2H````N4`````!QBG!=`TQP,8$!@"#P`$YR'+UC80DC````(V\)*@```")
M5"0(Z!7>__^Y#@```#'`BU0D"/.KZ=7]__^-<`3'``````#'1`C\`````(/F
M_"GP`<&#X?R#^00/@K']__^#X?PQP,<$!@````"#P`0YR'+RZ9G]__^`O"3N
M````00^%ZOK__X"\).\```!##X7<^O__@+PD\````$@/A<[Z__^`O"3Q````
M10^%P/K__VH":O]JQHMT)!16Z`_8__^#Q`QJ*8V$)/0```!05NB\UO__:*7"
M!`B-A"0``0``4&@\P00(_W0D(&AQP@0(:O]J`57H9]K__X/$,.F!^?__C;0F
M`````#'V9HET"/[I_OS__^@7U___C;0F`````%575E.#["C_-2PQ!0CHWMG_
M_XU4)!S&0&$!N%_!!`CHW.?__X/$$(7`=`F`.#$/A#P"``#HA_'__X/L#/\U
M+#$%".BIV?__:@MJ`6B?P@0(4.BJU___@\0@A<`/A*\```"#/6A!!0@!BT`,
MBW@8#XZ<````,?:[`0```.LMC78`BT4,@^P(4*%D004(_S28Z,S5__^#Q!"%
MP'5EH6A!!0B#PP&#Q@$YV'Y;@^P,_S4L,04(Z#C9__]J`%974.BNV/__@\0@
MA<!T-XLHBT4()0`$(``]``0``'2F@^P,_S4L,04(Z`C9__]J`FH`55#HC=;_
M_X/$(.N+D(VT)@````"A:$$%"(U0_SGR#X08`0``@^P,_S4L,04(Z-+8__]J
M`VH!:*3"!`A0Z-/6__^#Q""%P(G#=#2+0`R#[`R+,/\U+#$%".BGV/__@\0,
M:*;"!`A64.@8UO__BT,,@\00BQCV0PI`#X4``@``@^P,_S4L,04(Z'C8__]J
M`VH!:*O!!`A0Z'G6__^#Q""%P(G&=#F-5"0,N"W!!`CH8N;__X7`B<,/A%@!
M``"+1@R#[`R+./\U+#$%".@UV/__@\0,4U=0Z*K5__^#Q!"#[`S_-2PQ!0CH
M&=C__XU4)!S&0&$`N"3!!`CH%^;__X/$$(7`B<.C;$$%"`^$A0```(/L"&C`
M`0``4.BGUO__C5`!@\00@_H!=@F#^!$/A7D!``"#Q!Q;7E]=PXUV`(/X`0^.
MW_[__[L!````C78`C;PG`````(/L#/\U+#$%"(/#`>B?U___7EU74.AFU/__
M@\00.1UH004(?]OIIO[__XVV`````(!X`0`/A+_]___IM?W__Y"#[`S_-61!
M!0CH<O+__X/$$(7`HVQ!!0@/A.L```"+1@R+/61!!0B+&(M#""4`!"``/0`$
M```/A8T```"+0PR#[`A74.B'U/__B<>+1@R#Q!"+&(M#""4`!"``/0`$``!U
M28M##%=0H61!!0C_,&B8PP0(Z)C5__^0C;0F`````*%D004(@^P,BSB+1@R+
M&/\U+#$%".C6UO__B?J)V.BMZ?__@\00Z9[^__^#[`S_-2PQ!0CHM];__VH"
M:@!34.@\U/__@\0@ZYR#[`S_-2PQ!0CHF=;__VH":@!34.@>U/__@\0@Z57_
M__^#[`S_-2PQ!0CH>-;__UI94U#HC]7__X/$$.GA_?__@^P,:'3#!`CH^M3_
M_U"A9$$%"%/_,&C`PP0(Z.?4__^-M"8`````5E.#[!"+="0<5N@1[?__#[80
M@\00B<.$TG0@C4`!ZPH/MA"#P`&$TG01@/HO=?$/MA")PX/``832=>_HD.__
M_X7V=!Z%P'0:@#X`=!6#[`AH6<($"%/H1=+__X/$$#G8=`:#Q`1;7L.#Q`2)
M\%M>Z=SF__]FD&:09I!FD&:09I!3Z!K8__^!P^IO``"#[`B-@Q`!``"%P'0?
MBP!0_W0D'/]T)!S_="0<Z$/3__^#Q!A;PXVV`````#'`Z]]FD&:055=64^C7
MU___@<.G;P``@^P,BVPD((VSU/[__^B+T?__C8/0_O__*<;!_@*%]G0E,?^-
MM@````"#[`3_="0L_W0D+%7_E+O0_O__@\<!@\00.?=UXX/$#%M>7UW#C78`
M\\,``%.#[`CH<]?__X'#0V\``(/$"%O#`P````$``@`E<R\E<P`O<')O8R]S
M96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS
M.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!
M344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!
M4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`
M4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)
M0E)!4EE?4$%42`!32$Q)0E]0051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)
M4@!435``55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E
M<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`
M05)'5@`8`'!E<FP`+64`+2T`````7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("``````<&5R;'AS:2YC````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&5X96-U=&EO;B!O9B`E<R!F
M86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF
M:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY
M("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G
M.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M
M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P
M?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB
M4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@
M/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@
M>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P
M87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R
M;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@
M/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@
M/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D
M(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X
M(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^
M/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P
M,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O
M9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B
M3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D
M;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H
M)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E
M("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D
M8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P
M96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E
M*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92![
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F
M:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O
M('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE
M>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*
M?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA
M;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE
M;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I
M;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R
M:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N
M(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X
M*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T
M(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*
M?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A
M<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H
M)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF
M("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]
M96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*
M<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N
M(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*
M?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[V````!H```"@
MD/__]````+"4__\0#0``@)?__Q@!``!@HO__6`$``!"C__^\`0``8*/__^`!
M``!@I?__8`(``)"F__\4`P``,*?__W`#``#PI___#`0``""H__\T!```<*C_
M_VP$```PJ?__^`0``$"I__\,!0```*O__P@&```PJ___'`8``""L__]\!@``
MX*W__ZP&```PKO__R`8``&"N___L!@``8*___U@'``!@NO__-`L``!"^___$
M#```D+[__U`-``#0OO__A`T``#"____0#0``%``````````!>E(``7P(`1L,
M!`2(`0``(````!P```"DC___$`0````."$8.#$H/"W0$>``_&CLJ,B0B/```
M`$````!@EO__U@H```!!#@B%`D$.#(<#1`X0A@1!#A2#!48.[`(#Q`H.%$'#
M#A!!Q@X,0<<."$'%#@0``&````"``````*'__Z8`````20X(A0)!#@R'`T$.
M$(8$00X4@P5##C`"1`XT00XX00X\00Y`2`XP5PH.%$/##A!!Q@X,0<<."$'%
M#@1%"UH.%$7##A!!Q@X,0<<."$'%#@0````@````Y````$RA__]0`````$$.
M"(,"10X@`D@."$'##@0```!\````"`$``'BA___S`0```$$."(4"00X,AP-#
M#A"&!$$.%(,%1PY,20Y02`Y`6`Y,0PY02`Y``D<.3$<.4$H.0`)C"@X40<,.
M$$'&#@Q!QPX(0<4.!$@+`E`.2$$.3$$.4$@.0&T.3$L.4$@.0$X.1$$.2$D.
M3$4.4$P.0````+````"(`0``^*+__RD!````40X(A0)!#@R'`T$.$(8$00X4
M@P5(#IP!00Z@`4@.D`%.#IP!00Z@`4@.D`%7#IP!1`Z@`60.G`%!#I@!00Z<
M`4$.H`%%#J0!0@ZH`4(.K`%!#K`!2`Z4`44.F`%!#IP!0@Z@`4@.D`%8#IP!
M00Z@`4@.D`%##IP!00Z@`4@.D`%V#IP!00Z@`5`.D`%#"@X40<,.$$'&#@Q!
MQPX(0<4.!$4+`%@````\`@``=*/__Y$`````00X(@P)%#AQ&#B!(#A1&#AA!
M#AQ"#B!(#A!'"@X(0\,.!$$+0PX<1@X@3@X03PX<1@X@3@X03PX80@X<00X@
M2`X02`X(1,,.!```F````)@"``"XH___NP````!!#@B%`D$.#(<#0PX0A@1!
M#A2#!4@.M"!4#K@@10Z\($4.P"!(#K`@4PZT($$.N"!"#KP@00[`($@.L"!'
M#KP@1@[`($8.Q"!!#L@@00[,($$.T"!(#K`@5@H.%$'##A!!Q@X,0<<."$'%
M#@1%"TL.O"!&#L`@2`ZT($$.N"!!#KP@00[`($@.L"``)````#0#``#<H___
M)P````!##AQ&#B!*#B1%#BA%#BQ!#C!(#@0``#0```!<`P``Y*/__T0`````
M0PX<1@X@3@X<1@X@1@X<00X80@X<10X@10XD10XH10XL00XP2`X$B````)0#
M``#\H___L0````!!#@B'`D$.#(8#00X0@P1&#J!`5PZH0$4.K$!!#K!`10ZT
M0$4.N$!"#KQ`10[`0$@.H$!'#J1`10ZH0$@.K$!!#K!`2`Z@0$P.K$!!#K!`
M2`Z@0$D.I$!!#JA`00ZL0$$.L$!,#J!`6`H.$$'##@Q!Q@X(0<<.!$0+```0
M````(`0``#"D__\%`````````/@````T!```+*3__[@!````00X(A0)!#@R'
M`T$.$(8$00X4@P5&#L`@;@[(($0.S"!!#M`@2`[`(&P*#A1!PPX00<8.#$''
M#@A!Q0X$00M##LP@00[0($8.S"!!#L@@20[,($$.T"!(#L`@:P[(($$.S"!!
M#M`@2`[`($L.S"!!#M`@2`[`(&T.Q"!!#L@@10[,($$.T"!%#M0@10[8($(.
MW"!!#N`@2`[,($8.T"!(#L0@1@[(($$.S"!"#M`@2`[`($<.S"!&#M`@3@[`
M($\.R"!%#LP@0@[0($@.P"!*#L@@0@[,($$.T"!(#L`@4P[,($$.T"!(#L`@
M`!`````P!0``\*3__RT`````````7````$0%```,I?__YP````!!#@B#`D,.
M(%8.+$$.,$P.(&P.+$(.,$@.($\*#@A!PPX$0PM@"@X(0<,.!$\+80XD00XH
M00XL10XP2`X@2`H."$'##@1'"T,."$/##@0`+````*0%``"<I?__MP$```!!
M#@B'`D$.#(8#0PY``UL!"@X,0<8."$''#@1&"P``&````-0%```LI___3```
M``!3#B!M"@X$2`L``"````#P!0``8*?__R0`````0PX02`X<00X@2`X020H.
M!$,+`&@````4!@``;*?___L`````00X(A0)!#@R'`T8.$(8$00X4@P5(#E`"
M0@Y81`Y<00Y@2`Y0>0H.%$'##A!!Q@X,0<<."$'%#@1#"T,.7$0.8&0.5$$.
M6$4.7$0.8$4.9$(.:$(.;$$.<$P.4-@#``"`!@```*C___D*````00X(A0)!
M#@R'`T$.$(8$00X4@P5&#I""`@*G#IR"`D$.H(("3`Z0@@)##IR"`D$.H(("
M2`Z0@@)4#IR"`D0.H(("10ZD@@)"#JB"`D(.K(("00ZP@@)+#I""`@)##IR"
M`D$.H(("2`Z0@@("0PZ<@@)!#J""`D@.D(("5@Z<@@)##J""`D@.D((";PZ<
M@@)*#J""`DH.I(("1PZH@@)%#JR"`D$.L(("10ZT@@)"#KB"`D(.O(("00[`
M@@)(#IB"`D4.G(("00Z@@@)(#I""`D@.G(("1@Z@@@)(#I2"`D8.F(("1`Z<
M@@)"#J""`D@.D(("1PZ<@@)$#J""`D8.I(("10ZH@@)"#JR"`D8.L(("2`Z0
M@@)<"@X40<,.$$'&#@Q!QPX(0<4.!$@+3PH.F(("00Z<@@)$#J""`D8.I(("
M10ZH@@))"T,.G(("1@Z@@@).#I""`E,.G(("1@Z@@@)3#I""`DL.G(("1@Z@
M@@).#I""`E,.G(("00Z@@@)8#I""`DL.G(("00Z@@@)&#IR"`D$.F(("00Z<
M@@)&#J""`D@.D(("30Z<@@)!#J""`D@.D(("?@Z8@@)"#IR"`D$.H(("3`Z0
M@@)C#I2"`D$.F(("10Z<@@)%#J""`D4.I(("0@ZH@@)"#JR"`D$.L(("2`Z0
M@@):#IR"`D4.H(("00ZD@@)!#JB"`D4.K(("00ZP@@)%#K2"`D(.N(("0@Z\
M@@)!#L""`D@.D(("0PZ8@@)%#IR"`D$.H(("2`Z0@@)(#IR"`D0.H(("7`Z0
M@@).#IR"`D$.H(("6`Z0@@)T#IR"`D$.H(("2`Z0@@)L#I2"`D(.F(("0@Z<
M@@)%#J""`D@.E(("0@Z8@@)(#IR"`D$.H(("2`Z0@@):#I2"`D(.F(("0@Z<
M@@)$#J""`@)@#I""`D@.E(("10Z8@@)(#IR"`D0.H(("2`Z0@@("7PZ4@@)!
M#IB"`DH.G(("00Z@@@)8#I""`@+_#I2"`D$.F(("00Z<@@)(#J""`D\.D(("
M7`Z<@@)$#J""`FD.D(("`WD!#IR"`D$.H(("10ZD@@)"#JB"`D(.K(("00ZP
M@@)+#I""`E$.E(("10Z8@@)%#IR"`D0.H(("10ZD@@)"#JB"`D(.K(("00ZP
M@@)(#I""`E<.G(("00Z@@@),#I""`@+O#I2"`D(.F(("0@Z<@@)%#J""`D@.
ME(("0@Z8@@)(#IR"`D$.H(("2@ZD@@)(#JB"`D4.K(("1`ZP@@)%#K2"`D(.
MN(("0@Z\@@)!#L""`D@.D(("``",`0``7`H``"2O__^I`P```$$."(4"00X,
MAP-!#A"&!$$.%(,%0PX\1@Y`6@XP50X\1@Y`1PY$0@Y(10Y,00Y02`XP;0XX
M00X\2`Y`2`XP5@X\1@Y`1PY$00Y(00Y,00Y02`XP6`X\1@Y`1PY$0@Y(00Y,
M00Y02`XP70X\1@Y`1PY$0@Y(10Y,00Y02`XP3`X\2`Y`2`XT10XX00X\00Y`
M2PXP3PX\1@Y`1PY$0@Y(10Y,00Y02`XP9`X\2`Y`2`XT00XX00X\00Y`2`XP
M0PX\1@Y`6@XP4@XX10X\00Y`2PXP40H.%$'##A!!Q@X,0<<."$'%#@1$"UL.
M/$8.0$D./$$..$$./$$.0$@.,&8./$8.0$@.,'$..$$./$$.0$T.,%4*#C1!
M#CA'#CQ%#D!-"T@./$T.0%$.,$@./$8.0$<.1$(.2$$.3$$.4$@.,$4./$8.
M0$<.1$(.2$$.3$$.4$@.,$@./$8.0$8./$$..$$./$$.0$@.,$@*#CQ%#D!%
M"T$.-$8..$(./$4.0```2````.P+``!$L?__=`````!!#@B&`D$.#(,#0PX<
M10X@2PX0>PX810X<00X@2`X01PH.#$'##@A!Q@X$00M##@Q#PPX(0<8.!```
M`#P````X#```F(?__]T!````1`P!`$H0!0)U`$4/`W5T!A`&`G5\$`,"=7@#
M9`$*P0P!`$'#0<9!Q4,,!`1!"P`P````>`P``#BQ__\\`````$$."(,"3@X0
M30X41`X81`X<1`X@2`X(0<,.!$<.$(,"````2````*P,``!$L?__70````!!
M#@B%`D$.#(<#00X0A@1!#A2#!4X.(&D.)$0.*$0.+$$.,$T.($<.%$'##A!!
MQ@X,0<<."$'%#@0``!````#X#```6+'__P(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````T)@$"+"8!`@``````0````$````!````
MTP$```$````B`@```0```"X"```!````.0(```$```!#`@```0```%$"```!
M````7@(```P```#\D00(#0```+3`!`@9````T"X%"!L````$````&@```-0N
M!0@<````!````/7^_V^L@00(!0```&2)!`@&````!(,$"`H````+!0``"P``
M`!`````5``````````,`````,`4(`@`````"```4````$0```!<```#\CP0(
M$0```,R/!`@2````,````!,````(````_O__;SR/!`C___]O`@```/#__V]P
MC@0(````````````````````````````````````````````````````````
M`````````````-PN!0@``````````#:2!`A&D@0(5I($"&:2!`AVD@0(AI($
M"):2!`BFD@0(MI($",:2!`C6D@0(YI($"/:2!`@&DP0(%I,$"":3!`@VDP0(
M1I,$"%:3!`AFDP0(=I,$"(:3!`B6DP0(II,$"+:3!`C&DP0(UI,$".:3!`CV
MDP0(!I0$"!:4!`@FE`0(-I0$"$:4!`A6E`0(9I0$"':4!`B&E`0(EI0$"*:4
M!`BVE`0(QI0$"-:4!`CFE`0(]I0$"`:5!`@6E00()I4$"#:5!`A&E00(5I4$
M"&:5!`AVE00(AI4$"):5!`BFE00(MI4$",:5!`C6E00(YI4$"/:5!`@&E@0(
M%I8$"":6!`@``````````/____\$Q`0(1T-#.B`H1TY5*2`U+C,N,2`R,#$V
M,#0Q.0!'0T,Z("A'3E4I(#4N,RXQ(#(P,38P-3`S```N<VAS=')T86(`+FEN
M=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA
M<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?
M<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M``````L````!`````@```%2!!`A4`0``$P```````````````0`````````3
M````!P````(```!H@00(:`$``"````````````````0`````````(0````<`
M```"````B($$"(@!```D```````````````$`````````#0```#V__]O`@``
M`*R!!`BL`0``6`$```4`````````!`````0````^````"P````(````$@P0(
M!`,``&`&```&`````0````0````0````1@````,````"````9(D$"&0)```+
M!0`````````````!`````````$X```#___]O`@```'".!`AP#@``S`````4`
M`````````@````(```!;````_O__;P(````\CP0(/`\``)`````&`````@``
M``0`````````:@````D````"````S(\$",P/```P````!0`````````$````
M"````',````)````0@```/R/!`C\#P````(```4````,````!`````@```!\
M`````0````8```#\D00(_!$``",```````````````0`````````=P````$`
M```&````()($""`2```0!``````````````0````!````((````!````!@``
M`#"6!`@P%@``@BH`````````````$`````````"(`````0````8```"TP`0(
MM$```!0```````````````0`````````C@````$````"````R,`$",A```"X
M0``````````````$`````````)8````!`````@```(`!!0B`@0``W```````
M````````!`````````"D`````0````(```!<`@4(7((```P-````````````
M``0`````````K@````X````#````T"X%"-">```$```````````````$````
M`````+H````/`````P```-0N!0C4G@``!```````````````!`````````#&
M`````0````,```#8+@4(V)X```0```````````````0`````````RP````8`
M```#````W"X%"-R>```@`0``!@`````````$````"````-0````!`````P``
M`/PO!0C\GP``!```````````````!`````0```#9`````0````,`````,`4(
M`*````P!``````````````0````$````X@````$````#````##$%"`RA```0
M```````````````$`````````.@````(`````P```"`Q!0@<H0``5!``````
M````````(`````````#M`````0```#``````````'*$``#0`````````````
M``$````!`````0````,``````````````%"A``#V```````````````!````
$````````
